@@ -1,12 +1,11 @@
 test_that("`as_EBImage()` works", {
-  skip_if(win32bit())
   skip_if_not_installed("EBImage")
   img <- read_tif(system.file("img", "Rlogo.tif", package = "ijtiff"))
   expect_equal(dim(img), c(76, 100, 4, 1))
   ebimg <- as_EBImage(img)
   expect_equal(dim(ebimg), c(100, 76, 4, 1))
   expect_is(ebimg, "Image")
-  img <- read_tif(system.file("img", "2ch_ij.tif", package = "ijtiff"))
+  img <- read_tif(test_path("testthat-figs", "2ch_ij.tif"))
   expect_equal(dim(img), c(15, 6, 2, 5))
   ebimg <- as_EBImage(img)
   expect_equal(dim(ebimg), c(6, 15, 2, 5))
@@ -26,8 +25,10 @@ test_that("`as_EBImage()` works", {
   expect_equal(EBImage::colorMode(as_EBImage(arr)), 0)
   arr <- array(2^22, dim = rep(4, 4))
   expect_equal(EBImage::colorMode(as_EBImage(arr)), 2)
-  expect_lt(mean(EBImage::imageData(as_EBImage(arr))),
-    mean(EBImage::imageData(as_EBImage(array(2^33, dim = rep(4, 4))))))
+  expect_lt(
+    mean(EBImage::imageData(as_EBImage(arr))),
+    mean(EBImage::imageData(as_EBImage(array(2^33, dim = rep(4, 4)))))
+  )
   expect_equal(ebimg_install_msg(), paste0(
     "  * To install `EBImage`:", "\n",
     "    - Install `BiocManager` with `install.packages(\"BiocManager\")`.\n",
